@@ -5,11 +5,12 @@ which can in return be manipulated.
 
 import re as regex
 from sys import version_info
+
+from python_gedcom_2.element_creator import ElementCreator
+
 from python_gedcom_2.element.element import Element
 from python_gedcom_2.element.family import FamilyElement, NotAnActualFamilyError
-from python_gedcom_2.element.file import FileElement
 from python_gedcom_2.element.individual import IndividualElement, NotAnActualIndividualError
-from python_gedcom_2.element.object import ObjectElement
 from python_gedcom_2.element.root import RootElement
 import python_gedcom_2.tags
 
@@ -231,17 +232,7 @@ class Parser(object):
                              + "\nSee: https://chronoplexsoftware.com/gedcomvalidator/gedcom/gedcom-5.5.pdf")
             raise GedcomFormatViolationError(error_message)
 
-        # Create element. Store in list and dict, create children and parents.
-        if tag == python_gedcom_2.tags.GEDCOM_TAG_INDIVIDUAL:
-            element = IndividualElement(level, pointer, tag, value, crlf, multi_line=False)
-        elif tag == python_gedcom_2.tags.GEDCOM_TAG_FAMILY:
-            element = FamilyElement(level, pointer, tag, value, crlf, multi_line=False)
-        elif tag == python_gedcom_2.tags.GEDCOM_TAG_FILE:
-            element = FileElement(level, pointer, tag, value, crlf, multi_line=False)
-        elif tag == python_gedcom_2.tags.GEDCOM_TAG_OBJECT:
-            element = ObjectElement(level, pointer, tag, value, crlf, multi_line=False)
-        else:
-            element = Element(level, pointer, tag, value, crlf, multi_line=False)
+        element = ElementCreator.create_element(level, pointer, tag, value, crlf, is_multiline=False)
 
         # Start with last element as parent, back up if necessary.
         parent_element = last_element
@@ -435,6 +426,46 @@ class Parser(object):
 
         return parents
 
+    def get_children(self, individual, child_type="ALL"):
+        """Return elements corresponding to children of an individual.
+
+        Optional child_type. Default "ALL" returns all children. "NAT" can be
+        used to specify only natural (genetic) children.
+
+        :type individual: IndividualElement
+        :type child_type: str
+        :rtype: list of IndividualElement
+        """
+        if not isinstance(individual, IndividualElement):
+            raise NotAnActualIndividualError(
+                "Operation only valid for elements with %s tag" % python_gedcom_2.tags.GEDCOM_TAG_INDIVIDUAL
+            )
+
+        children = []
+        families = self.get_families(individual, python_gedcom_2.tags.GEDCOM_TAG_FAMILY_SPOUSE)
+
+        for family in families:
+            if child_type == "NAT":
+                # Find our relationship to the children - is this parent male or female?
+                type_of_our_individual = None
+                for family_member in family.get_child_elements():  # Will look like "1 HUSB @I1@", "1 WIFE @I2@", or "1 CHIL @I3@"
+                    if family_member.get_value() == individual.get_pointer():
+                        if family_member.get_tag() == python_gedcom_2.tags.GEDCOM_TAG_WIFE:
+                            type_of_our_individual = python_gedcom_2.tags.GEDCOM_PROGRAM_DEFINED_TAG_MREL
+                        elif family_member.get_tag() == python_gedcom_2.tags.GEDCOM_TAG_HUSBAND:
+                            type_of_our_individual = python_gedcom_2.tags.GEDCOM_PROGRAM_DEFINED_TAG_FREL
+
+                for family_member in family.get_child_elements():  # Will look like "1 HUSB @I1@", "1 WIFE @I2@", or "1 CHIL @I3@"
+                    if family_member.get_tag() == python_gedcom_2.tags.GEDCOM_TAG_CHILD:
+                        for child in family_member.get_child_elements():
+                            if child.get_value() == "Natural":
+                                if child.get_tag() == type_of_our_individual:
+                                    children.append(self.get_element_by_pointer(family_member.get_value()))
+            else:
+                children += self.get_family_members(family, python_gedcom_2.tags.GEDCOM_TAG_CHILD)
+
+        return children
+
     def find_path_to_ancestor(self, descendant, ancestor, path=None):
         """Return path from descendant to ancestor
         :rtype: object
